summaryrefslogtreecommitdiffstats
path: root/quanta/utility/quantacommon.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/utility/quantacommon.h')
-rw-r--r--quanta/utility/quantacommon.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/quanta/utility/quantacommon.h b/quanta/utility/quantacommon.h
index 91e08f57..586b7e50 100644
--- a/quanta/utility/quantacommon.h
+++ b/quanta/utility/quantacommon.h
@@ -35,7 +35,7 @@ class KStandardDirs;
class TQWidget;
class Tag;
-class KConfig;
+class TDEConfig;
class KPopupMenu;
/** Describes one abbreviation group */
@@ -196,20 +196,20 @@ pointer must be deleted by the caller!! */
static bool checkOverwrite(const KURL& url, TQWidget *window);
/**
* Same as KConfigBase::readPathListEntry, but resolves symlinks
* @param config
* @param pKey
* @return
*/
- static TQStringList readPathListEntry(KConfig *config, const TQString &pKey);
+ static TQStringList readPathListEntry(TDEConfig *config, const TQString &pKey);
/**
* Same as KConfigBase::readPathEntry, but resolves symlinks
* @param config
* @param pKey
* @return
*/
- static TQString readPathEntry(KConfig *config, const TQString &pKey);
+ static TQString readPathEntry(TDEConfig *config, const TQString &pKey);
/**
* Returns the HTML encoding string for character with the specified code.
@@ -196,20 +196,20 @@ pointer must be deleted by the caller!! */
static bool checkOverwrite(const KURL& url, TQWidget *window);
/**
- * Same as KConfigBase::readPathListEntry, but resolves symlinks
+ * Same as TDEConfigBase::readPathListEntry, but resolves symlinks
* @param config
* @param pKey
@@ -196,20 +196,20 @@ pointer must be deleted by the caller!! */
/**
- * Same as KConfigBase::readPathEntry, but resolves symlinks
+ * Same as TDEConfigBase::readPathEntry, but resolves symlinks
* @param config
* @param pKey